==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-es_MX-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Spanish (Mexico) (http://www.transifex.com/tine20/tine20/language/es_MX/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: es_MX\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "Línea"

, "Caller Id"
: "Identificador de Llamada"

, "Start"
: "Comenzar"

, "Connected"
: "Conectado"

, "Disconnected"
: "Desconectado"

, "Duration"
: "Duración"

, "Ringing"
: "Timbrando"

, "Direction"
: "Orientación"

, "Source"
: "Origen"

, "Destination"
: "Destino"

, "Phone"
: ""

, "Phones"
: "Teléfonos"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "Número"

, "Cancel"
: "Cancelar"

, "Dial"
: "Marcar"

, "Error"
: "Error"

, "Not possible to dial."
: "No fue posible marcar."

, "Edit phone settings"
: "Editar preferencias del teléfono"

, "Dial number"
: "Marcar número"

, "Initiate a new outgoing call"
: "Comenzar una nueva llamada de salida"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: "Llamar a contacto"

, "Work"
: "Trabajo"

, "Home"
: "Casa"

, "Cell"
: "Celular"

, "Cell private"
: "Celular Privado"

, "Incoming call"
: "Llamada entrante"

, "Outgoing call"
: "Llamada de salida"

, "unknown number"
: "número desconocido"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.08.8.tar.bz2: Phone/js/Phone-lang-es_MX-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Spanish (Mexico) (http://www.transifex.com/tine20/tine20/language/es_MX/)\nLanguage: es_MX\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Llamada entrante"

, "Outgoing call"
: "Llamada de salida"

, "unknown number"
: "número desconocido"

, "Phone"
: ""

, "Line"
: "Línea"

, "Number"
: "Número"

, "Cancel"
: "Cancelar"

, "Dial"
: "Marcar"

, "Error"
: "Error"

, "Not possible to dial."
: "No fue posible marcar."

, "Call contact"
: "Llamar a contacto"

, "Work"
: "Trabajo"

, "Home"
: "Casa"

, "Cell"
: "Celular"

, "Cell private"
: "Celular Privado"

, "Edit phone settings"
: "Editar preferencias del teléfono"

, "Dial number"
: "Marcar número"

, "Initiate a new outgoing call"
: "Comenzar una nueva llamada de salida"

, "Phones"
: "Teléfonos"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "Identificador de Llamada"

, "Start"
: "Comenzar"

, "Connected"
: "Conectado"

, "Disconnected"
: "Desconectado"

, "Duration"
: "Duración"

, "Ringing"
: "Timbrando"

, "Direction"
: "Orientación"

, "Source"
: "Origen"

, "Destination"
: "Destino"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
